==> string_schema-0.1.0.tar.gz: string_schema-0.1.0/docs/README.md <==
# Simple Schema Documentation

Welcome to the Simple Schema documentation! This directory contains comprehensive documentation for the Simple Schema library.

## 🎯 Status: Production Ready

✅ **All tests passing** (66/66 tests pass)
✅ **Critical bugs fixed** (array parsing now works correctly)
✅ **Complete feature set** (all enhanced syntax working)
✅ **Comprehensive documentation** (getting started, API reference, examples)
✅ **Clean architecture** (modular, extensible design)

## 📚 Documentation Structure

### **Getting Started**

- **[Getting Started](getting-started.md)** - Installation, quick start, and progressive examples
- **[String Syntax](string-syntax.md)** - Complete guide to string-based schema syntax
- **[FAQ](faq.md)** - Frequently asked questions and common use cases

### **Reference Documentation**

- **[API Reference](api-reference.md)** - Complete API documentation
- **[Examples](examples.md)** - Real-world examples and practical patterns
- **[Advanced Usage](advanced-usage.md)** - Complex patterns, optimization, and enterprise use

### **Help & Support**

- **[Troubleshooting](troubleshooting.md)** - Common issues and solutions

## Quick Links

### For Beginners

- [Installation](getting-started.md#installation)
- [Your First Schema](getting-started.md#your-first-schema)
- [Basic Examples](examples.md#basic-examples)

### For Developers

- [Core API](api-reference.md#core-api)
- [String Parsing](api-reference.md#string-parsing)
- [Validation](api-reference.md#validation)

### For Integration

- [Pydantic Integration](integrations.md#pydantic)
- [JSON Schema Export](integrations.md#json-schema)
- [OpenAPI Integration](integrations.md#openapi)

## Key Features

Simple Schema provides:

- **Intuitive Syntax**: Define schemas using simple, readable syntax
- **LLM-Optimized**: Designed to work seamlessly with Large Language Models
- **Multiple Formats**: Export to JSON Schema, Pydantic models, OpenAPI specs
- **Rich Validation**: Comprehensive validation with detailed error reporting
- **Type Safety**: Full type support with constraints and format hints
- **Extensible**: Easy to extend with custom types and validators

## Getting Help

- Check the [FAQ](faq.md) for common questions
- Browse [Examples](examples.md) for practical use cases
- Review [API Reference](api-reference.md) for detailed documentation
- See [Troubleshooting](troubleshooting.md) for common issues

## Contributing

See the main repository for contribution guidelines and development setup.

## License

Simple Schema is released under the MIT License. See the LICENSE file for details.

==> string_schema-0.1.3.tar.gz: string_schema-0.1.3/docs/README.md <==
# String Schema Documentation

Welcome to the String Schema documentation! This directory contains comprehensive documentation for the String Schema library.

## 🎯 Status: Production Ready

✅ **All tests passing** (66/66 tests pass)
✅ **Critical bugs fixed** (array parsing now works correctly)
✅ **Complete feature set** (all enhanced syntax working)
✅ **Comprehensive documentation** (getting started, API reference, examples)
✅ **Clean architecture** (modular, extensible design)

## 📚 Documentation Structure

### **Getting Started**

- **[Getting Started](getting-started.md)** - Installation, quick start, and progressive examples
- **[String Syntax](string-syntax.md)** - Complete guide to string-based schema syntax
- **[FAQ](faq.md)** - Frequently asked questions and common use cases

### **Reference Documentation**

- **[API Reference](api-reference.md)** - Complete API documentation
- **[Examples](examples.md)** - Real-world examples and practical patterns
- **[Advanced Usage](advanced-usage.md)** - Complex patterns, optimization, and enterprise use

### **Help & Support**

- **[Troubleshooting](troubleshooting.md)** - Common issues and solutions

## Quick Links

### For Beginners

- [Installation](getting-started.md#installation)
- [Your First Schema](getting-started.md#your-first-schema)
- [Basic Examples](examples.md#basic-examples)

### For Developers

- [Core API](api-reference.md#core-api)
- [String Parsing](api-reference.md#string-parsing)
- [Validation](api-reference.md#validation)

### For Integration

- [Pydantic Integration](integrations.md#pydantic)
- [JSON Schema Export](integrations.md#json-schema)
- [OpenAPI Integration](integrations.md#openapi)

## Key Features

String Schema provides:

- **Intuitive Syntax**: Define schemas using simple, readable string syntax
- **LLM-Optimized**: Designed to work seamlessly with Large Language Models
- **Multiple Formats**: Export to JSON Schema, Pydantic models, OpenAPI specs
- **Rich Validation**: Comprehensive validation with detailed error reporting
- **Type Safety**: Full type support with constraints and format hints
- **Extensible**: Easy to extend with custom types and validators

## Getting Help

- Check the [FAQ](faq.md) for common questions
- Browse [Examples](examples.md) for practical use cases
- Review [API Reference](api-reference.md) for detailed documentation
- See [Troubleshooting](troubleshooting.md) for common issues

## Contributing

See the main repository for contribution guidelines and development setup.

## License

String Schema is released under the MIT License. See the LICENSE file for details.
